{
    name: 测试配置
    data: [
        (1,.2,.03,4e-4,500)
        {
            // 中文当key
            代号=嘿嘿
            age = ???
            # 字符串里有特殊符合，还是要用引号括起来
            'a:b':"{c,d,e,f}"
        }
    ]
}