{
text= 
r"""在json格式基础上加了些其他东西，让配置写起来更简单：
    1，字符串可以不用引号括起来，程序判断字段不是整数，小数，布尔型等类型后，当字段是字符串
    2，可以写注释，//,#,/**/, ###...###，其中/*note*/和###note###是多行注释
    3，分号;和逗号,和换行\n等价，等于号=和冒号:等价，括号()和中括号[]等价
    4，加了python的字符串书写方式："...", '...', r"..."，r'...', r'''...'''
    5，输出格式化
    6，可配置化

运行以下命令会打印文件名格式化后的样式:
    python -m buildz xf 文件名

比如:

文件test.js:
---------
{
    name: 测试配置
    data: [
        (1,.2,.03,4e-4,500)
        {
            // 中文当key
            代号=嘿嘿
            age = ???
            # 字符串里有特殊符合，还是要用引号括起来
            'a:b':"{c,d,e,f}"
        }
    ]
}
---------
运行:
python -m buildz xf test.js
"""
}